moodlmth
========
Convert raw HTML pages into python source code

Usage
-----
```bash
# Convert web page
moodlmth https://google.com

# Convert HTML file
moodlmth /filepath/index.html -o index.py

# Force conversion
moodlmth index.html -o index.py --fast --debug
```
